# Setup file
set {profile(AGCI EarthPulse Notes,authentication)} {}
set {profile(AGCI EarthPulse Notes,comstack)} tcpip
set {profile(AGCI EarthPulse Notes,databases)} epnotes
set {profile(AGCI EarthPulse Notes,description)} {}
set {profile(AGCI EarthPulse Notes,host)} gcrio.org
set {profile(AGCI EarthPulse Notes,idAuthentication)} {}
set {profile(AGCI EarthPulse Notes,largeSetLowerBound)} 2
set {profile(AGCI EarthPulse Notes,maxResultSets)} {}
set {profile(AGCI EarthPulse Notes,maxResultSize)} {}
set {profile(AGCI EarthPulse Notes,maxTerms)} {}
set {profile(AGCI EarthPulse Notes,maximumRecordSize)} 50000
set {profile(AGCI EarthPulse Notes,mediumSetPresentNumber)} 0
set {profile(AGCI EarthPulse Notes,multipleDatabases)} 0
set {profile(AGCI EarthPulse Notes,namedResultSets)} 1
set {profile(AGCI EarthPulse Notes,port)} 6674
set {profile(AGCI EarthPulse Notes,preferredMessageSize)} 30000
set {profile(AGCI EarthPulse Notes,presentChunk)} 4
set {profile(AGCI EarthPulse Notes,protocol)} Z39
set {profile(AGCI EarthPulse Notes,queryCCL)} 0
set {profile(AGCI EarthPulse Notes,queryRPN)} 1
set {profile(AGCI EarthPulse Notes,recentNews)} {}
set {profile(AGCI EarthPulse Notes,smallSetUpperBound)} 0
set {profile(AGCI EarthPulse Notes,targetInfoName)} {}
set {profile(AGCI EarthPulse Notes,timeDefine)} 944954141
set {profile(AGCI EarthPulse Notes,timeLastExplain)} {}
set {profile(AGCI EarthPulse Notes,timeLastInit)} 944957715
set {profile(AGCI EarthPulse Notes,welcomeMessage)} {}
set {profile(AGCI EarthPulse Notes,windowNumber)} 1
set {profile(AGCI Elements of Change,authentication)} {}
set {profile(AGCI Elements of Change,comstack)} tcpip
set {profile(AGCI Elements of Change,databases)} eoc
set {profile(AGCI Elements of Change,description)} {}
set {profile(AGCI Elements of Change,host)} gcrio.org
set {profile(AGCI Elements of Change,idAuthentication)} {}
set {profile(AGCI Elements of Change,largeSetLowerBound)} 2
set {profile(AGCI Elements of Change,maxResultSets)} {}
set {profile(AGCI Elements of Change,maxResultSize)} {}
set {profile(AGCI Elements of Change,maxTerms)} {}
set {profile(AGCI Elements of Change,maximumRecordSize)} 50000
set {profile(AGCI Elements of Change,mediumSetPresentNumber)} 0
set {profile(AGCI Elements of Change,multipleDatabases)} 0
set {profile(AGCI Elements of Change,namedResultSets)} 1
set {profile(AGCI Elements of Change,port)} 6671
set {profile(AGCI Elements of Change,preferredMessageSize)} 30000
set {profile(AGCI Elements of Change,presentChunk)} 4
set {profile(AGCI Elements of Change,protocol)} Z39
set {profile(AGCI Elements of Change,queryCCL)} 0
set {profile(AGCI Elements of Change,queryRPN)} 1
set {profile(AGCI Elements of Change,recentNews)} {}
set {profile(AGCI Elements of Change,smallSetUpperBound)} 0
set {profile(AGCI Elements of Change,targetInfoName)} {}
set {profile(AGCI Elements of Change,timeDefine)} 944954152
set {profile(AGCI Elements of Change,timeLastExplain)} {}
set {profile(AGCI Elements of Change,timeLastInit)} 971260539
set {profile(AGCI Elements of Change,welcomeMessage)} {}
set {profile(AGCI Elements of Change,windowNumber)} 2
set profile(AGCI,authentication) {}
set profile(AGCI,comstack) tcpip
set profile(AGCI,description) {}
set profile(AGCI,host) {}
set profile(AGCI,idAuthentication) {}
set profile(AGCI,largeSetLowerBound) 2
set profile(AGCI,maxResultSets) {}
set profile(AGCI,maxResultSize) {}
set profile(AGCI,maxTerms) {}
set profile(AGCI,maximumRecordSize) 50000
set profile(AGCI,mediumSetPresentNumber) 0
set profile(AGCI,multipleDatabases) 0
set profile(AGCI,namedResultSets) 1
set profile(AGCI,port) 210
set profile(AGCI,preferredMessageSize) 30000
set profile(AGCI,presentChunk) 4
set profile(AGCI,protocol) Z39
set profile(AGCI,queryCCL) 0
set profile(AGCI,queryRPN) 1
set profile(AGCI,recentNews) {}
set profile(AGCI,smallSetUpperBound) 0
set profile(AGCI,targetInfoName) {}
set profile(AGCI,targetMaxResultSets) {}
set profile(AGCI,targetMaxResultSize) {}
set profile(AGCI,targetMaxTerms) {}
set profile(AGCI,timeDefine) 944954173
set profile(AGCI,timeLastExplain) {}
set profile(AGCI,timeLastInit) {}
set profile(AGCI,welcomeMessage) {}
set profile(AGCI,windowNumber) 15
set profile(BIBSYS,authentication) {}
set profile(BIBSYS,comstack) tcpip
set profile(BIBSYS,databases) {BIBSYS PERI}
set profile(BIBSYS,description) {}
set profile(BIBSYS,host) z3950.bibsys.no
set profile(BIBSYS,idAuthentication) {}
set profile(BIBSYS,largeSetLowerBound) 2
set profile(BIBSYS,maxResultSets) {}
set profile(BIBSYS,maxResultSize) {}
set profile(BIBSYS,maxTerms) {}
set profile(BIBSYS,maximumRecordSize) 50000
set profile(BIBSYS,mediumSetPresentNumber) 0
set profile(BIBSYS,multipleDatabases) 0
set profile(BIBSYS,namedResultSets) 1
set profile(BIBSYS,port) 210
set profile(BIBSYS,preferredMessageSize) 30000
set profile(BIBSYS,presentChunk) 4
set profile(BIBSYS,protocol) Z39
set profile(BIBSYS,queryCCL) 0
set profile(BIBSYS,queryRPN) 1
set profile(BIBSYS,recentNews) {}
set profile(BIBSYS,smallSetUpperBound) 0
set profile(BIBSYS,targetInfoName) {}
set profile(BIBSYS,timeDefine) 944954177
set profile(BIBSYS,timeLastExplain) {}
set profile(BIBSYS,timeLastInit) {}
set profile(BIBSYS,welcomeMessage) {}
set profile(BIBSYS,windowNumber) 4
set {profile(Bell Laboratories Library Network,authentication)} {}
set {profile(Bell Laboratories Library Network,comstack)} tcpip
set {profile(Bell Laboratories Library Network,databases)} {books factbook gils netlib}
set {profile(Bell Laboratories Library Network,description)} {}
set {profile(Bell Laboratories Library Network,host)} z3950.bell-labs.com
set {profile(Bell Laboratories Library Network,idAuthentication)} {}
set {profile(Bell Laboratories Library Network,largeSetLowerBound)} 2
set {profile(Bell Laboratories Library Network,maxResultSets)} {}
set {profile(Bell Laboratories Library Network,maxResultSize)} {}
set {profile(Bell Laboratories Library Network,maxTerms)} {}
set {profile(Bell Laboratories Library Network,maximumRecordSize)} 50000
set {profile(Bell Laboratories Library Network,mediumSetPresentNumber)} 0
set {profile(Bell Laboratories Library Network,multipleDatabases)} 0
set {profile(Bell Laboratories Library Network,namedResultSets)} 1
set {profile(Bell Laboratories Library Network,port)} 210
set {profile(Bell Laboratories Library Network,preferredMessageSize)} 30000
set {profile(Bell Laboratories Library Network,presentChunk)} 4
set {profile(Bell Laboratories Library Network,protocol)} Z39
set {profile(Bell Laboratories Library Network,queryCCL)} 0
set {profile(Bell Laboratories Library Network,queryRPN)} 1
set {profile(Bell Laboratories Library Network,recentNews)} {}
set {profile(Bell Laboratories Library Network,smallSetUpperBound)} 0
set {profile(Bell Laboratories Library Network,targetInfoName)} {}
set {profile(Bell Laboratories Library Network,timeDefine)} {}
set {profile(Bell Laboratories Library Network,timeLastExplain)} {}
set {profile(Bell Laboratories Library Network,timeLastInit)} 944953393
set {profile(Bell Laboratories Library Network,welcomeMessage)} {}
set {profile(Bell Laboratories Library Network,windowNumber)} 16
set {profile(Bibliotheque Nationale du Quebec,authentication)} {}
set {profile(Bibliotheque Nationale du Quebec,comstack)} tcpip
set {profile(Bibliotheque Nationale du Quebec,databases)} IRIS
set {profile(Bibliotheque Nationale du Quebec,description)} {}
set {profile(Bibliotheque Nationale du Quebec,host)} www.biblinat.gouv.qc.ca
set {profile(Bibliotheque Nationale du Quebec,idAuthentication)} {}
set {profile(Bibliotheque Nationale du Quebec,largeSetLowerBound)} 2
set {profile(Bibliotheque Nationale du Quebec,maxResultSets)} {}
set {profile(Bibliotheque Nationale du Quebec,maxResultSize)} {}
set {profile(Bibliotheque Nationale du Quebec,maxTerms)} {}
set {profile(Bibliotheque Nationale du Quebec,maximumRecordSize)} 50000
set {profile(Bibliotheque Nationale du Quebec,mediumSetPresentNumber)} 0
set {profile(Bibliotheque Nationale du Quebec,multipleDatabases)} 0
set {profile(Bibliotheque Nationale du Quebec,namedResultSets)} 1
set {profile(Bibliotheque Nationale du Quebec,port)} 210
set {profile(Bibliotheque Nationale du Quebec,preferredMessageSize)} 30000
set {profile(Bibliotheque Nationale du Quebec,presentChunk)} 4
set {profile(Bibliotheque Nationale du Quebec,protocol)} Z39
set {profile(Bibliotheque Nationale du Quebec,queryCCL)} 0
set {profile(Bibliotheque Nationale du Quebec,queryRPN)} 1
set {profile(Bibliotheque Nationale du Quebec,recentNews)} {}
set {profile(Bibliotheque Nationale du Quebec,smallSetUpperBound)} 0
set {profile(Bibliotheque Nationale du Quebec,targetInfoName)} {}
set {profile(Bibliotheque Nationale du Quebec,timeDefine)} 944954227
set {profile(Bibliotheque Nationale du Quebec,timeLastExplain)} {}
set {profile(Bibliotheque Nationale du Quebec,timeLastInit)} 944955787
set {profile(Bibliotheque Nationale du Quebec,welcomeMessage)} {}
set {profile(Bibliotheque Nationale du Quebec,windowNumber)} 9
set {profile(Colorado Alliance of Research Libraries,authentication)} {}
set {profile(Colorado Alliance of Research Libraries,comstack)} tcpip
set {profile(Colorado Alliance of Research Libraries,databases)} {AIM ARA BEM CDE CSP DPL EST LAM LUT MCC MIN NEL NEU NJC OTE PPC PUE RGU RRC STR TKO TRI WYO}
set {profile(Colorado Alliance of Research Libraries,description)} {}
set {profile(Colorado Alliance of Research Libraries,host)} 192.54.81.3
set {profile(Colorado Alliance of Research Libraries,idAuthentication)} {}
set {profile(Colorado Alliance of Research Libraries,largeSetLowerBound)} 2
set {profile(Colorado Alliance of Research Libraries,maxResultSets)} {}
set {profile(Colorado Alliance of Research Libraries,maxResultSize)} {}
set {profile(Colorado Alliance of Research Libraries,maxTerms)} {}
set {profile(Colorado Alliance of Research Libraries,maximumRecordSize)} 50000
set {profile(Colorado Alliance of Research Libraries,mediumSetPresentNumber)} 0
set {profile(Colorado Alliance of Research Libraries,multipleDatabases)} 0
set {profile(Colorado Alliance of Research Libraries,namedResultSets)} 1
set {profile(Colorado Alliance of Research Libraries,port)} 210
set {profile(Colorado Alliance of Research Libraries,preferredMessageSize)} 30000
set {profile(Colorado Alliance of Research Libraries,presentChunk)} 4
set {profile(Colorado Alliance of Research Libraries,protocol)} Z39
set {profile(Colorado Alliance of Research Libraries,queryCCL)} 0
set {profile(Colorado Alliance of Research Libraries,queryRPN)} 1
set {profile(Colorado Alliance of Research Libraries,recentNews)} {}
set {profile(Colorado Alliance of Research Libraries,smallSetUpperBound)} 0
set {profile(Colorado Alliance of Research Libraries,targetInfoName)} {}
set {profile(Colorado Alliance of Research Libraries,timeDefine)} 944954480
set {profile(Colorado Alliance of Research Libraries,timeLastExplain)} {}
set {profile(Colorado Alliance of Research Libraries,timeLastInit)} {}
set {profile(Colorado Alliance of Research Libraries,welcomeMessage)} {}
set {profile(Colorado Alliance of Research Libraries,windowNumber)} 14
set {profile(DTV Alis,authentication)} {}
set {profile(DTV Alis,comstack)} tcpip
set {profile(DTV Alis,databases)} DTV01
set {profile(DTV Alis,description)} {}
set {profile(DTV Alis,host)} odin.dtv.dk
set {profile(DTV Alis,idAuthentication)} {}
set {profile(DTV Alis,largeSetLowerBound)} 2
set {profile(DTV Alis,maxResultSets)} {}
set {profile(DTV Alis,maxResultSize)} {}
set {profile(DTV Alis,maxTerms)} {}
set {profile(DTV Alis,maximumRecordSize)} 50000
set {profile(DTV Alis,mediumSetPresentNumber)} 0
set {profile(DTV Alis,multipleDatabases)} 0
set {profile(DTV Alis,namedResultSets)} 1
set {profile(DTV Alis,port)} 210
set {profile(DTV Alis,preferredMessageSize)} 30000
set {profile(DTV Alis,presentChunk)} 4
set {profile(DTV Alis,protocol)} Z39
set {profile(DTV Alis,queryCCL)} 0
set {profile(DTV Alis,queryRPN)} 1
set {profile(DTV Alis,recentNews)} {}
set {profile(DTV Alis,smallSetUpperBound)} 0
set {profile(DTV Alis,targetInfoName)} {}
set {profile(DTV Alis,timeDefine)} 944954772
set {profile(DTV Alis,timeLastExplain)} {}
set {profile(DTV Alis,timeLastInit)} 944956585
set {profile(DTV Alis,welcomeMessage)} {}
set {profile(DTV Alis,windowNumber)} 6
set {profile(DanBib V2,authentication)} {}
set {profile(DanBib V2,comstack)} tcpip
set {profile(DanBib V2,databases)} danbibv2
set {profile(DanBib V2,description)} {}
set {profile(DanBib V2,host)} z3950-test.dbc.dk
set {profile(DanBib V2,idAuthentication)} {}
set {profile(DanBib V2,largeSetLowerBound)} 2
set {profile(DanBib V2,maxResultSets)} {}
set {profile(DanBib V2,maxResultSize)} {}
set {profile(DanBib V2,maxTerms)} {}
set {profile(DanBib V2,maximumRecordSize)} 50000
set {profile(DanBib V2,mediumSetPresentNumber)} 0
set {profile(DanBib V2,multipleDatabases)} 0
set {profile(DanBib V2,namedResultSets)} 1
set {profile(DanBib V2,port)} 210
set {profile(DanBib V2,preferredMessageSize)} 30000
set {profile(DanBib V2,presentChunk)} 4
set {profile(DanBib V2,protocol)} Z39
set {profile(DanBib V2,queryCCL)} 0
set {profile(DanBib V2,queryRPN)} 1
set {profile(DanBib V2,recentNews)} {}
set {profile(DanBib V2,smallSetUpperBound)} 0
set {profile(DanBib V2,targetInfoName)} {}
set {profile(DanBib V2,timeDefine)} 944954541
set {profile(DanBib V2,timeLastExplain)} {}
set {profile(DanBib V2,timeLastInit)} 1007339533
set {profile(DanBib V2,welcomeMessage)} {}
set {profile(DanBib V2,windowNumber)} 12
set {profile(Data Research Associates,authentication)} {}
set {profile(Data Research Associates,comstack)} tcpip
set {profile(Data Research Associates,databases)} DREWDB
set {profile(Data Research Associates,description)} {}
set {profile(Data Research Associates,host)} dranet.dra.com
set {profile(Data Research Associates,idAuthentication)} {}
set {profile(Data Research Associates,largeSetLowerBound)} 2
set {profile(Data Research Associates,maxResultSets)} {}
set {profile(Data Research Associates,maxResultSize)} {}
set {profile(Data Research Associates,maxTerms)} {}
set {profile(Data Research Associates,maximumRecordSize)} 50000
set {profile(Data Research Associates,mediumSetPresentNumber)} 0
set {profile(Data Research Associates,multipleDatabases)} 0
set {profile(Data Research Associates,namedResultSets)} 1
set {profile(Data Research Associates,port)} 210
set {profile(Data Research Associates,preferredMessageSize)} 30000
set {profile(Data Research Associates,presentChunk)} 4
set {profile(Data Research Associates,protocol)} Z39
set {profile(Data Research Associates,queryCCL)} 0
set {profile(Data Research Associates,queryRPN)} 1
set {profile(Data Research Associates,recentNews)} {}
set {profile(Data Research Associates,smallSetUpperBound)} 0
set {profile(Data Research Associates,targetInfoName)} {}
set {profile(Data Research Associates,timeDefine)} 944954622
set {profile(Data Research Associates,timeLastExplain)} {}
set {profile(Data Research Associates,timeLastInit)} 983197460
set {profile(Data Research Associates,welcomeMessage)} {}
set {profile(Data Research Associates,windowNumber)} 5
set profile(Default,authentication) {}
set profile(Default,comstack) tcpip
set profile(Default,description) {}
set profile(Default,host) {}
set profile(Default,largeSetLowerBound) 2
set profile(Default,maxResultSets) {}
set profile(Default,maxResultSize) {}
set profile(Default,maxTerms) {}
set profile(Default,maximumRecordSize) 50000
set profile(Default,mediumSetPresentNumber) 0
set profile(Default,multipleDatabases) 0
set profile(Default,namedResultSets) 1
set profile(Default,port) 210
set profile(Default,preferredMessageSize) 30000
set profile(Default,presentChunk) 4
set profile(Default,protocol) Z39
set profile(Default,queryCCL) 0
set profile(Default,queryRPN) 1
set profile(Default,recentNews) {}
set profile(Default,smallSetUpperBound) 0
set profile(Default,targetInfoName) {}
set profile(Default,timeDefine) {}
set profile(Default,timeLastExplain) {}
set profile(Default,timeLastInit) {}
set profile(Default,welcomeMessage) {}
set profile(Default,windowNumber) 22
set {profile(Emory Library Catalog,authentication)} {}
set {profile(Emory Library Catalog,comstack)} tcpip
set {profile(Emory Library Catalog,databases)} unicorn
set {profile(Emory Library Catalog,description)} {}
set {profile(Emory Library Catalog,host)} library.cc.emory.edu
set {profile(Emory Library Catalog,idAuthentication)} {}
set {profile(Emory Library Catalog,largeSetLowerBound)} 2
set {profile(Emory Library Catalog,maxResultSets)} {}
set {profile(Emory Library Catalog,maxResultSize)} {}
set {profile(Emory Library Catalog,maxTerms)} {}
set {profile(Emory Library Catalog,maximumRecordSize)} 50000
set {profile(Emory Library Catalog,mediumSetPresentNumber)} 0
set {profile(Emory Library Catalog,multipleDatabases)} 0
set {profile(Emory Library Catalog,namedResultSets)} 1
set {profile(Emory Library Catalog,port)} 2200
set {profile(Emory Library Catalog,preferredMessageSize)} 30000
set {profile(Emory Library Catalog,presentChunk)} 4
set {profile(Emory Library Catalog,protocol)} Z39
set {profile(Emory Library Catalog,queryCCL)} 0
set {profile(Emory Library Catalog,queryRPN)} 1
set {profile(Emory Library Catalog,recentNews)} {}
set {profile(Emory Library Catalog,smallSetUpperBound)} 0
set {profile(Emory Library Catalog,targetInfoName)} {}
set {profile(Emory Library Catalog,timeDefine)} 944954832
set {profile(Emory Library Catalog,timeLastExplain)} {}
set {profile(Emory Library Catalog,timeLastInit)} 971250665
set {profile(Emory Library Catalog,welcomeMessage)} {}
set {profile(Emory Library Catalog,windowNumber)} 10
set profile(LOC,authentication) {}
set profile(LOC,comstack) tcpip
set profile(LOC,databases) voyager
set profile(LOC,description) {}
set profile(LOC,host) z3950.loc.gov
set profile(LOC,idAuthentication) {}
set profile(LOC,largeSetLowerBound) 2
set profile(LOC,maxResultSets) {}
set profile(LOC,maxResultSize) {}
set profile(LOC,maxTerms) {}
set profile(LOC,maximumRecordSize) 50000
set profile(LOC,mediumSetPresentNumber) 0
set profile(LOC,multipleDatabases) 0
set profile(LOC,namedResultSets) 1
set profile(LOC,port) 7090
set profile(LOC,preferredMessageSize) 30000
set profile(LOC,presentChunk) 4
set profile(LOC,protocol) Z39
set profile(LOC,queryCCL) 0
set profile(LOC,queryRPN) 1
set profile(LOC,recentNews) {}
set profile(LOC,smallSetUpperBound) 0
set profile(LOC,targetInfoName) {}
set profile(LOC,targetMaxResultSets) {}
set profile(LOC,targetMaxResultSize) {}
set profile(LOC,targetMaxTerms) {}
set profile(LOC,timeDefine) 983197488
set profile(LOC,timeLastExplain) {}
set profile(LOC,timeLastInit) 1030712459
set profile(LOC,welcomeMessage) {}
set profile(LOC,windowNumber) 7
set {profile(OCLC First Search,authentication)} {}
set {profile(OCLC First Search,comstack)} tcpip
set {profile(OCLC First Search,databases)} {INSPEC HumanitiesIndex LibraryLiterature LegalPeriodicals MarcWorldCat Medline NewYorkTimes}
set {profile(OCLC First Search,description)} {}
set {profile(OCLC First Search,host)} Tikal.dev.oclc.org
set {profile(OCLC First Search,idAuthentication)} {}
set {profile(OCLC First Search,largeSetLowerBound)} 2
set {profile(OCLC First Search,maxResultSets)} {}
set {profile(OCLC First Search,maxResultSize)} {}
set {profile(OCLC First Search,maxTerms)} {}
set {profile(OCLC First Search,maximumRecordSize)} 50000
set {profile(OCLC First Search,mediumSetPresentNumber)} 0
set {profile(OCLC First Search,multipleDatabases)} 0
set {profile(OCLC First Search,namedResultSets)} 1
set {profile(OCLC First Search,port)} 210
set {profile(OCLC First Search,preferredMessageSize)} 30000
set {profile(OCLC First Search,presentChunk)} 4
set {profile(OCLC First Search,protocol)} Z39
set {profile(OCLC First Search,queryCCL)} 0
set {profile(OCLC First Search,queryRPN)} 1
set {profile(OCLC First Search,recentNews)} {}
set {profile(OCLC First Search,smallSetUpperBound)} 0
set {profile(OCLC First Search,targetInfoName)} {}
set {profile(OCLC First Search,timeDefine)} 944955039
set {profile(OCLC First Search,timeLastExplain)} {}
set {profile(OCLC First Search,timeLastInit)} {}
set {profile(OCLC First Search,welcomeMessage)} {}
set {profile(OCLC First Search,windowNumber)} 11
set {profile(Royal Library of Denmark,authentication)} {}
set {profile(Royal Library of Denmark,comstack)} tcpip
set {profile(Royal Library of Denmark,databases)} {BGF01 BHS01 DJM01 DRA01 GRB01 KAB01 KBB01 KBH01 KBK01 KDM01 KLG01 KUI01 KVF01 NIA01 SAB01}
set {profile(Royal Library of Denmark,description)} {}
set {profile(Royal Library of Denmark,host)} z3950.kb.dk
set {profile(Royal Library of Denmark,idAuthentication)} {}
set {profile(Royal Library of Denmark,largeSetLowerBound)} 2
set {profile(Royal Library of Denmark,maxResultSets)} {}
set {profile(Royal Library of Denmark,maxResultSize)} {}
set {profile(Royal Library of Denmark,maxTerms)} {}
set {profile(Royal Library of Denmark,maximumRecordSize)} 50000
set {profile(Royal Library of Denmark,mediumSetPresentNumber)} 0
set {profile(Royal Library of Denmark,multipleDatabases)} 0
set {profile(Royal Library of Denmark,namedResultSets)} 1
set {profile(Royal Library of Denmark,port)} 2100
set {profile(Royal Library of Denmark,preferredMessageSize)} 30000
set {profile(Royal Library of Denmark,presentChunk)} 4
set {profile(Royal Library of Denmark,protocol)} Z39
set {profile(Royal Library of Denmark,queryCCL)} 0
set {profile(Royal Library of Denmark,queryRPN)} 1
set {profile(Royal Library of Denmark,recentNews)} {}
set {profile(Royal Library of Denmark,smallSetUpperBound)} 0
set {profile(Royal Library of Denmark,targetInfoName)} {}
set {profile(Royal Library of Denmark,timeDefine)} 944955289
set {profile(Royal Library of Denmark,timeLastExplain)} {}
set {profile(Royal Library of Denmark,timeLastInit)} 944955294
set {profile(Royal Library of Denmark,welcomeMessage)} {}
set {profile(Royal Library of Denmark,windowNumber)} 3
set {profile(University of Arkansas,authentication)} {}
set {profile(University of Arkansas,comstack)} tcpip
set {profile(University of Arkansas,databases)} Marion
set {profile(University of Arkansas,description)} {}
set {profile(University of Arkansas,host)} libils.ualr.edu
set {profile(University of Arkansas,idAuthentication)} {}
set {profile(University of Arkansas,largeSetLowerBound)} 2
set {profile(University of Arkansas,maxResultSets)} {}
set {profile(University of Arkansas,maxResultSize)} {}
set {profile(University of Arkansas,maxTerms)} {}
set {profile(University of Arkansas,maximumRecordSize)} 50000
set {profile(University of Arkansas,mediumSetPresentNumber)} 0
set {profile(University of Arkansas,multipleDatabases)} 0
set {profile(University of Arkansas,namedResultSets)} 1
set {profile(University of Arkansas,port)} 210
set {profile(University of Arkansas,preferredMessageSize)} 30000
set {profile(University of Arkansas,presentChunk)} 4
set {profile(University of Arkansas,protocol)} Z39
set {profile(University of Arkansas,queryCCL)} 0
set {profile(University of Arkansas,queryRPN)} 1
set {profile(University of Arkansas,recentNews)} {}
set {profile(University of Arkansas,smallSetUpperBound)} 0
set {profile(University of Arkansas,targetInfoName)} {}
set {profile(University of Arkansas,timeDefine)} 944956252
set {profile(University of Arkansas,timeLastExplain)} {}
set {profile(University of Arkansas,timeLastInit)} 971251409
set {profile(University of Arkansas,welcomeMessage)} {}
set {profile(University of Arkansas,windowNumber)} 17
set {profile(University of British Columbia,authentication)} {}
set {profile(University of British Columbia,comstack)} tcpip
set {profile(University of British Columbia,databases)} MARION
set {profile(University of British Columbia,description)} {}
set {profile(University of British Columbia,host)} dra.library.ubc.ca
set {profile(University of British Columbia,idAuthentication)} {}
set {profile(University of British Columbia,largeSetLowerBound)} 2
set {profile(University of British Columbia,maxResultSets)} {}
set {profile(University of British Columbia,maxResultSize)} {}
set {profile(University of British Columbia,maxTerms)} {}
set {profile(University of British Columbia,maximumRecordSize)} 50000
set {profile(University of British Columbia,mediumSetPresentNumber)} 0
set {profile(University of British Columbia,multipleDatabases)} 0
set {profile(University of British Columbia,namedResultSets)} 1
set {profile(University of British Columbia,port)} 210
set {profile(University of British Columbia,preferredMessageSize)} 30000
set {profile(University of British Columbia,presentChunk)} 4
set {profile(University of British Columbia,protocol)} Z39
set {profile(University of British Columbia,queryCCL)} 0
set {profile(University of British Columbia,queryRPN)} 1
set {profile(University of British Columbia,recentNews)} {}
set {profile(University of British Columbia,smallSetUpperBound)} 0
set {profile(University of British Columbia,targetInfoName)} {}
set {profile(University of British Columbia,timeDefine)} 944955536
set {profile(University of British Columbia,timeLastExplain)} {}
set {profile(University of British Columbia,timeLastInit)} 944955627
set {profile(University of British Columbia,welcomeMessage)} {}
set {profile(University of British Columbia,windowNumber)} 21
set {profile(University of California MELVYL,authentication)} {}
set {profile(University of California MELVYL,comstack)} tcpip
set {profile(University of California MELVYL,databases)} PE
set {profile(University of California MELVYL,description)} {}
set {profile(University of California MELVYL,host)} melvyl.ucop.edu
set {profile(University of California MELVYL,idAuthentication)} {}
set {profile(University of California MELVYL,largeSetLowerBound)} 2
set {profile(University of California MELVYL,maxResultSets)} {}
set {profile(University of California MELVYL,maxResultSize)} {}
set {profile(University of California MELVYL,maxTerms)} {}
set {profile(University of California MELVYL,maximumRecordSize)} 50000
set {profile(University of California MELVYL,mediumSetPresentNumber)} 0
set {profile(University of California MELVYL,multipleDatabases)} 0
set {profile(University of California MELVYL,namedResultSets)} 1
set {profile(University of California MELVYL,port)} 210
set {profile(University of California MELVYL,preferredMessageSize)} 30000
set {profile(University of California MELVYL,presentChunk)} 4
set {profile(University of California MELVYL,protocol)} Z39
set {profile(University of California MELVYL,queryCCL)} 0
set {profile(University of California MELVYL,queryRPN)} 1
set {profile(University of California MELVYL,recentNews)} {}
set {profile(University of California MELVYL,smallSetUpperBound)} 0
set {profile(University of California MELVYL,targetInfoName)} {}
set {profile(University of California MELVYL,timeDefine)} 944955670
set {profile(University of California MELVYL,timeLastExplain)} {}
set {profile(University of California MELVYL,timeLastInit)} 944955675
set {profile(University of California MELVYL,welcomeMessage)} {}
set {profile(University of California MELVYL,windowNumber)} 19
set {profile(University of Illinois,authentication)} {}
set {profile(University of Illinois,comstack)} tcpip
set {profile(University of Illinois,databases)} {UICOPAC2 UICOPAC1}
set {profile(University of Illinois,description)} {}
set {profile(University of Illinois,host)} owl.cc.uic.edu
set {profile(University of Illinois,idAuthentication)} {}
set {profile(University of Illinois,largeSetLowerBound)} 2
set {profile(University of Illinois,maxResultSets)} {}
set {profile(University of Illinois,maxResultSize)} {}
set {profile(University of Illinois,maxTerms)} {}
set {profile(University of Illinois,maximumRecordSize)} 50000
set {profile(University of Illinois,mediumSetPresentNumber)} 0
set {profile(University of Illinois,multipleDatabases)} 0
set {profile(University of Illinois,namedResultSets)} 1
set {profile(University of Illinois,port)} 210
set {profile(University of Illinois,preferredMessageSize)} 30000
set {profile(University of Illinois,presentChunk)} 4
set {profile(University of Illinois,protocol)} Z39
set {profile(University of Illinois,queryCCL)} 0
set {profile(University of Illinois,queryRPN)} 1
set {profile(University of Illinois,recentNews)} {}
set {profile(University of Illinois,smallSetUpperBound)} 0
set {profile(University of Illinois,targetInfoName)} {}
set {profile(University of Illinois,timeDefine)} 944955869
set {profile(University of Illinois,timeLastExplain)} {}
set {profile(University of Illinois,timeLastInit)} 1007339488
set {profile(University of Illinois,welcomeMessage)} {}
set {profile(University of Illinois,windowNumber)} 8
set profile(indexdata,authentication) {}
set profile(indexdata,comstack) tcpip
set profile(indexdata,databases) {dranet.dra.com IR-Explain-1 gils marc zoom}
set profile(indexdata,description) {}
set profile(indexdata,host) bagel.indexdata.dk
set profile(indexdata,idAuthentication) {}
set profile(indexdata,largeSetLowerBound) 2
set profile(indexdata,maxResultSets) {}
set profile(indexdata,maxResultSize) {}
set profile(indexdata,maxTerms) {}
set profile(indexdata,maximumRecordSize) 50000
set profile(indexdata,mediumSetPresentNumber) 0
set profile(indexdata,multipleDatabases) 1
set profile(indexdata,namedResultSets) 1
set profile(indexdata,port) 210
set profile(indexdata,preferredMessageSize) 30000
set profile(indexdata,presentChunk) 4
set profile(indexdata,protocol) Z39
set profile(indexdata,queryCCL) 0
set profile(indexdata,queryRPN) 1
set profile(indexdata,recentNews) {}
set profile(indexdata,smallSetUpperBound) 0
set profile(indexdata,targetInfoName) Zebra
set profile(indexdata,timeDefine) 944954185
set profile(indexdata,timeLastExplain) 1007339347
set profile(indexdata,timeLastInit) 1043924972
set profile(indexdata,welcomeMessage) {}
set profile(indexdata,windowNumber) 20
set profile(localhost,authentication) {}
set profile(localhost,comstack) tcpip
set profile(localhost,databases) Default
set profile(localhost,description) {}
set profile(localhost,host) localhost
set profile(localhost,idAuthentication) {}
set profile(localhost,largeSetLowerBound) 2
set profile(localhost,maxResultSets) {}
set profile(localhost,maxResultSize) {}
set profile(localhost,maxTerms) {}
set profile(localhost,maximumRecordSize) 50000
set profile(localhost,mediumSetPresentNumber) 0
set profile(localhost,multipleDatabases) 0
set profile(localhost,namedResultSets) 1
set profile(localhost,port) 9999
set profile(localhost,preferredMessageSize) 30000
set profile(localhost,presentChunk) 4
set profile(localhost,protocol) Z39
set profile(localhost,queryCCL) 0
set profile(localhost,queryRPN) 1
set profile(localhost,recentNews) {}
set profile(localhost,smallSetUpperBound) 0
set profile(localhost,targetInfoName) {}
set profile(localhost,timeDefine) 1007339366
set profile(localhost,timeLastExplain) {}
set profile(localhost,timeLastInit) 1046896330
set profile(localhost,welcomeMessage) {}
set profile(localhost,windowNumber) 13
set queryTypes Simple
set queryButtons {{{I 0} {I 1} {I 2}}}
set queryInfo {{{Title {1=4}} {Author 1=1003} {Subject 1=21} {Any {1=1016}} {Abstract {1=62}}}}
